<?php

/** @generate-class-entries */

class IntlChar
{
    /**
     * @var string
     * @cvalue U_UNICODE_VERSION
     */
    public const UNICODE_VERSION = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_MIN_VALUE
     */
    public const CODEPOINT_MIN = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_MAX_VALUE
     */
    public const CODEPOINT_MAX = UNKNOWN;
    /**
     * @var float
     * @cvalue U_NO_NUMERIC_VALUE
     */
    public const NO_NUMERIC_VALUE = UNKNOWN;

    /**
     * @var int
     * @cvalue UCHAR_ALPHABETIC
     */
    public const PROPERTY_ALPHABETIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_BINARY_START
     */
    public const PROPERTY_BINARY_START = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_ASCII_HEX_DIGIT
     */
    public const PROPERTY_ASCII_HEX_DIGIT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_BIDI_CONTROL
     */
    public const PROPERTY_BIDI_CONTROL = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_BIDI_MIRRORED
     */
    public const PROPERTY_BIDI_MIRRORED = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_DASH
     */
    public const PROPERTY_DASH = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_DEFAULT_IGNORABLE_CODE_POINT
     */
    public const PROPERTY_DEFAULT_IGNORABLE_CODE_POINT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_DEPRECATED
     */
    public const PROPERTY_DEPRECATED = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_DIACRITIC
     */
    public const PROPERTY_DIACRITIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_EXTENDER
     */
    public const PROPERTY_EXTENDER = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_FULL_COMPOSITION_EXCLUSION
     */
    public const PROPERTY_FULL_COMPOSITION_EXCLUSION = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_GRAPHEME_BASE
     */
    public const PROPERTY_GRAPHEME_BASE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_GRAPHEME_EXTEND
     */
    public const PROPERTY_GRAPHEME_EXTEND = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_GRAPHEME_LINK
     */
    public const PROPERTY_GRAPHEME_LINK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_HEX_DIGIT
     */
    public const PROPERTY_HEX_DIGIT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_HYPHEN
     */
    public const PROPERTY_HYPHEN = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_ID_CONTINUE
     */
    public const PROPERTY_ID_CONTINUE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_ID_START
     */
    public const PROPERTY_ID_START = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_IDEOGRAPHIC
     */
    public const PROPERTY_IDEOGRAPHIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_IDS_BINARY_OPERATOR
     */
    public const PROPERTY_IDS_BINARY_OPERATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_IDS_TRINARY_OPERATOR
     */
    public const PROPERTY_IDS_TRINARY_OPERATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_JOIN_CONTROL
     */
    public const PROPERTY_JOIN_CONTROL = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_LOGICAL_ORDER_EXCEPTION
     */
    public const PROPERTY_LOGICAL_ORDER_EXCEPTION = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_LOWERCASE
     */
    public const PROPERTY_LOWERCASE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_MATH
     */
    public const PROPERTY_MATH = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NONCHARACTER_CODE_POINT
     */
    public const PROPERTY_NONCHARACTER_CODE_POINT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_QUOTATION_MARK
     */
    public const PROPERTY_QUOTATION_MARK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_RADICAL
     */
    public const PROPERTY_RADICAL = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_SOFT_DOTTED
     */
    public const PROPERTY_SOFT_DOTTED = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_TERMINAL_PUNCTUATION
     */
    public const PROPERTY_TERMINAL_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_UNIFIED_IDEOGRAPH
     */
    public const PROPERTY_UNIFIED_IDEOGRAPH = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_UPPERCASE
     */
    public const PROPERTY_UPPERCASE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_WHITE_SPACE
     */
    public const PROPERTY_WHITE_SPACE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_XID_CONTINUE
     */
    public const PROPERTY_XID_CONTINUE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_XID_START
     */
    public const PROPERTY_XID_START = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CASE_SENSITIVE
     */
    public const PROPERTY_CASE_SENSITIVE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_S_TERM
     */
    public const PROPERTY_S_TERM = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_VARIATION_SELECTOR
     */
    public const PROPERTY_VARIATION_SELECTOR = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NFD_INERT
     */
    public const PROPERTY_NFD_INERT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NFKD_INERT
     */
    public const PROPERTY_NFKD_INERT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NFC_INERT
     */
    public const PROPERTY_NFC_INERT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NFKC_INERT
     */
    public const PROPERTY_NFKC_INERT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_SEGMENT_STARTER
     */
    public const PROPERTY_SEGMENT_STARTER = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_PATTERN_SYNTAX
     */
    public const PROPERTY_PATTERN_SYNTAX = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_PATTERN_WHITE_SPACE
     */
    public const PROPERTY_PATTERN_WHITE_SPACE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_POSIX_ALNUM
     */
    public const PROPERTY_POSIX_ALNUM = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_POSIX_BLANK
     */
    public const PROPERTY_POSIX_BLANK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_POSIX_GRAPH
     */
    public const PROPERTY_POSIX_GRAPH = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_POSIX_PRINT
     */
    public const PROPERTY_POSIX_PRINT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_POSIX_XDIGIT
     */
    public const PROPERTY_POSIX_XDIGIT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CASED
     */
    public const PROPERTY_CASED = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CASE_IGNORABLE
     */
    public const PROPERTY_CASE_IGNORABLE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CHANGES_WHEN_LOWERCASED
     */
    public const PROPERTY_CHANGES_WHEN_LOWERCASED = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CHANGES_WHEN_UPPERCASED
     */
    public const PROPERTY_CHANGES_WHEN_UPPERCASED = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CHANGES_WHEN_TITLECASED
     */
    public const PROPERTY_CHANGES_WHEN_TITLECASED = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CHANGES_WHEN_CASEFOLDED
     */
    public const PROPERTY_CHANGES_WHEN_CASEFOLDED = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CHANGES_WHEN_CASEMAPPED
     */
    public const PROPERTY_CHANGES_WHEN_CASEMAPPED = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CHANGES_WHEN_NFKC_CASEFOLDED
     */
    public const PROPERTY_CHANGES_WHEN_NFKC_CASEFOLDED = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_BINARY_LIMIT
     */
    public const PROPERTY_BINARY_LIMIT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_BIDI_CLASS
     */
    public const PROPERTY_BIDI_CLASS = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_INT_START
     */
    public const PROPERTY_INT_START = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_BLOCK
     */
    public const PROPERTY_BLOCK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CANONICAL_COMBINING_CLASS
     */
    public const PROPERTY_CANONICAL_COMBINING_CLASS = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_DECOMPOSITION_TYPE
     */
    public const PROPERTY_DECOMPOSITION_TYPE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_EAST_ASIAN_WIDTH
     */
    public const PROPERTY_EAST_ASIAN_WIDTH = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_GENERAL_CATEGORY
     */
    public const PROPERTY_GENERAL_CATEGORY = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_JOINING_GROUP
     */
    public const PROPERTY_JOINING_GROUP = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_JOINING_TYPE
     */
    public const PROPERTY_JOINING_TYPE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_LINE_BREAK
     */
    public const PROPERTY_LINE_BREAK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NUMERIC_TYPE
     */
    public const PROPERTY_NUMERIC_TYPE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_SCRIPT
     */
    public const PROPERTY_SCRIPT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_HANGUL_SYLLABLE_TYPE
     */
    public const PROPERTY_HANGUL_SYLLABLE_TYPE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NFD_QUICK_CHECK
     */
    public const PROPERTY_NFD_QUICK_CHECK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NFKD_QUICK_CHECK
     */
    public const PROPERTY_NFKD_QUICK_CHECK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NFC_QUICK_CHECK
     */
    public const PROPERTY_NFC_QUICK_CHECK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NFKC_QUICK_CHECK
     */
    public const PROPERTY_NFKC_QUICK_CHECK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_LEAD_CANONICAL_COMBINING_CLASS
     */
    public const PROPERTY_LEAD_CANONICAL_COMBINING_CLASS = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_TRAIL_CANONICAL_COMBINING_CLASS
     */
    public const PROPERTY_TRAIL_CANONICAL_COMBINING_CLASS = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_GRAPHEME_CLUSTER_BREAK
     */
    public const PROPERTY_GRAPHEME_CLUSTER_BREAK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_SENTENCE_BREAK
     */
    public const PROPERTY_SENTENCE_BREAK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_WORD_BREAK
     */
    public const PROPERTY_WORD_BREAK = UNKNOWN;
#if U_ICU_VERSION_MAJOR_NUM >= 52
    /**
     * @var int
     * @cvalue UCHAR_BIDI_PAIRED_BRACKET_TYPE
     */
    public const PROPERTY_BIDI_PAIRED_BRACKET_TYPE = UNKNOWN;
#endif
    /**
     * @var int
     * @cvalue UCHAR_INT_LIMIT
     */
    public const PROPERTY_INT_LIMIT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_GENERAL_CATEGORY_MASK
     */
    public const PROPERTY_GENERAL_CATEGORY_MASK = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_MASK_START
     */
    public const PROPERTY_MASK_START = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_MASK_LIMIT
     */
    public const PROPERTY_MASK_LIMIT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NUMERIC_VALUE
     */
    public const PROPERTY_NUMERIC_VALUE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_DOUBLE_START
     */
    public const PROPERTY_DOUBLE_START = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_DOUBLE_LIMIT
     */
    public const PROPERTY_DOUBLE_LIMIT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_AGE
     */
    public const PROPERTY_AGE = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_STRING_START
     */
    public const PROPERTY_STRING_START = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_BIDI_MIRRORING_GLYPH
     */
    public const PROPERTY_BIDI_MIRRORING_GLYPH = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_CASE_FOLDING
     */
    public const PROPERTY_CASE_FOLDING = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_ISO_COMMENT
     */
    public const PROPERTY_ISO_COMMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_LOWERCASE_MAPPING
     */
    public const PROPERTY_LOWERCASE_MAPPING = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_NAME
     */
    public const PROPERTY_NAME = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_SIMPLE_CASE_FOLDING
     */
    public const PROPERTY_SIMPLE_CASE_FOLDING = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_SIMPLE_LOWERCASE_MAPPING
     */
    public const PROPERTY_SIMPLE_LOWERCASE_MAPPING = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_SIMPLE_TITLECASE_MAPPING
     */
    public const PROPERTY_SIMPLE_TITLECASE_MAPPING = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_SIMPLE_UPPERCASE_MAPPING
     */
    public const PROPERTY_SIMPLE_UPPERCASE_MAPPING = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_TITLECASE_MAPPING
     */
    public const PROPERTY_TITLECASE_MAPPING = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_UNICODE_1_NAME
     */
    public const PROPERTY_UNICODE_1_NAME = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_UPPERCASE_MAPPING
     */
    public const PROPERTY_UPPERCASE_MAPPING = UNKNOWN;
#if U_ICU_VERSION_MAJOR_NUM >= 52
    /**
     * @var int
     * @cvalue UCHAR_BIDI_PAIRED_BRACKET
     */
    public const PROPERTY_BIDI_PAIRED_BRACKET = UNKNOWN;
#endif
    /**
     * @var int
     * @cvalue UCHAR_STRING_LIMIT
     */
    public const PROPERTY_STRING_LIMIT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_SCRIPT_EXTENSIONS
     */
    public const PROPERTY_SCRIPT_EXTENSIONS = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_OTHER_PROPERTY_START
     */
    public const PROPERTY_OTHER_PROPERTY_START = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_OTHER_PROPERTY_LIMIT
     */
    public const PROPERTY_OTHER_PROPERTY_LIMIT = UNKNOWN;
    /**
     * @var int
     * @cvalue UCHAR_INVALID_CODE
     */
    public const PROPERTY_INVALID_CODE = UNKNOWN;

    /**
     * @var int
     * @cvalue U_UNASSIGNED
     */
    public const CHAR_CATEGORY_UNASSIGNED = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GENERAL_OTHER_TYPES
     */
    public const CHAR_CATEGORY_GENERAL_OTHER_TYPES = UNKNOWN;
    /**
     * @var int
     * @cvalue U_UPPERCASE_LETTER
     */
    public const CHAR_CATEGORY_UPPERCASE_LETTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LOWERCASE_LETTER
     */
    public const CHAR_CATEGORY_LOWERCASE_LETTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_TITLECASE_LETTER
     */
    public const CHAR_CATEGORY_TITLECASE_LETTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_MODIFIER_LETTER
     */
    public const CHAR_CATEGORY_MODIFIER_LETTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_OTHER_LETTER
     */
    public const CHAR_CATEGORY_OTHER_LETTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_NON_SPACING_MARK
     */
    public const CHAR_CATEGORY_NON_SPACING_MARK = UNKNOWN;
    /**
     * @var int
     * @cvalue U_ENCLOSING_MARK
     */
    public const CHAR_CATEGORY_ENCLOSING_MARK = UNKNOWN;
    /**
     * @var int
     * @cvalue U_COMBINING_SPACING_MARK
     */
    public const CHAR_CATEGORY_COMBINING_SPACING_MARK = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DECIMAL_DIGIT_NUMBER
     */
    public const CHAR_CATEGORY_DECIMAL_DIGIT_NUMBER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LETTER_NUMBER
     */
    public const CHAR_CATEGORY_LETTER_NUMBER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_OTHER_NUMBER
     */
    public const CHAR_CATEGORY_OTHER_NUMBER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SPACE_SEPARATOR
     */
    public const CHAR_CATEGORY_SPACE_SEPARATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LINE_SEPARATOR
     */
    public const CHAR_CATEGORY_LINE_SEPARATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_PARAGRAPH_SEPARATOR
     */
    public const CHAR_CATEGORY_PARAGRAPH_SEPARATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_CONTROL_CHAR
     */
    public const CHAR_CATEGORY_CONTROL_CHAR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_FORMAT_CHAR
     */
    public const CHAR_CATEGORY_FORMAT_CHAR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_PRIVATE_USE_CHAR
     */
    public const CHAR_CATEGORY_PRIVATE_USE_CHAR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SURROGATE
     */
    public const CHAR_CATEGORY_SURROGATE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DASH_PUNCTUATION
     */
    public const CHAR_CATEGORY_DASH_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_START_PUNCTUATION
     */
    public const CHAR_CATEGORY_START_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_END_PUNCTUATION
     */
    public const CHAR_CATEGORY_END_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_CONNECTOR_PUNCTUATION
     */
    public const CHAR_CATEGORY_CONNECTOR_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_OTHER_PUNCTUATION
     */
    public const CHAR_CATEGORY_OTHER_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_MATH_SYMBOL
     */
    public const CHAR_CATEGORY_MATH_SYMBOL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_CURRENCY_SYMBOL
     */
    public const CHAR_CATEGORY_CURRENCY_SYMBOL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_MODIFIER_SYMBOL
     */
    public const CHAR_CATEGORY_MODIFIER_SYMBOL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_OTHER_SYMBOL
     */
    public const CHAR_CATEGORY_OTHER_SYMBOL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_INITIAL_PUNCTUATION
     */
    public const CHAR_CATEGORY_INITIAL_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_FINAL_PUNCTUATION
     */
    public const CHAR_CATEGORY_FINAL_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_CHAR_CATEGORY_COUNT
     */
    public const CHAR_CATEGORY_CHAR_CATEGORY_COUNT = UNKNOWN;

    /**
     * @var int
     * @cvalue U_LEFT_TO_RIGHT
     */
    public const CHAR_DIRECTION_LEFT_TO_RIGHT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_RIGHT_TO_LEFT
     */
    public const CHAR_DIRECTION_RIGHT_TO_LEFT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_EUROPEAN_NUMBER
     */
    public const CHAR_DIRECTION_EUROPEAN_NUMBER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_EUROPEAN_NUMBER_SEPARATOR
     */
    public const CHAR_DIRECTION_EUROPEAN_NUMBER_SEPARATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_EUROPEAN_NUMBER_TERMINATOR
     */
    public const CHAR_DIRECTION_EUROPEAN_NUMBER_TERMINATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_ARABIC_NUMBER
     */
    public const CHAR_DIRECTION_ARABIC_NUMBER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_COMMON_NUMBER_SEPARATOR
     */
    public const CHAR_DIRECTION_COMMON_NUMBER_SEPARATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_BLOCK_SEPARATOR
     */
    public const CHAR_DIRECTION_BLOCK_SEPARATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SEGMENT_SEPARATOR
     */
    public const CHAR_DIRECTION_SEGMENT_SEPARATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WHITE_SPACE_NEUTRAL
     */
    public const CHAR_DIRECTION_WHITE_SPACE_NEUTRAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_OTHER_NEUTRAL
     */
    public const CHAR_DIRECTION_OTHER_NEUTRAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LEFT_TO_RIGHT_EMBEDDING
     */
    public const CHAR_DIRECTION_LEFT_TO_RIGHT_EMBEDDING = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LEFT_TO_RIGHT_OVERRIDE
     */
    public const CHAR_DIRECTION_LEFT_TO_RIGHT_OVERRIDE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_RIGHT_TO_LEFT_ARABIC
     */
    public const CHAR_DIRECTION_RIGHT_TO_LEFT_ARABIC = UNKNOWN;
    /**
     * @var int
     * @cvalue U_RIGHT_TO_LEFT_EMBEDDING
     */
    public const CHAR_DIRECTION_RIGHT_TO_LEFT_EMBEDDING = UNKNOWN;
    /**
     * @var int
     * @cvalue U_RIGHT_TO_LEFT_OVERRIDE
     */
    public const CHAR_DIRECTION_RIGHT_TO_LEFT_OVERRIDE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_POP_DIRECTIONAL_FORMAT
     */
    public const CHAR_DIRECTION_POP_DIRECTIONAL_FORMAT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DIR_NON_SPACING_MARK
     */
    public const CHAR_DIRECTION_DIR_NON_SPACING_MARK = UNKNOWN;
    /**
     * @var int
     * @cvalue U_BOUNDARY_NEUTRAL
     */
    public const CHAR_DIRECTION_BOUNDARY_NEUTRAL = UNKNOWN;
#if U_ICU_VERSION_MAJOR_NUM >= 52
    /**
     * @var int
     * @cvalue U_FIRST_STRONG_ISOLATE
     */
    public const CHAR_DIRECTION_FIRST_STRONG_ISOLATE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LEFT_TO_RIGHT_ISOLATE
     */
    public const CHAR_DIRECTION_LEFT_TO_RIGHT_ISOLATE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_RIGHT_TO_LEFT_ISOLATE
     */
    public const CHAR_DIRECTION_RIGHT_TO_LEFT_ISOLATE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_POP_DIRECTIONAL_ISOLATE
     */
    public const CHAR_DIRECTION_POP_DIRECTIONAL_ISOLATE = UNKNOWN;
#endif
    /**
     * @var int
     * @cvalue U_CHAR_DIRECTION_COUNT
     */
    public const CHAR_DIRECTION_CHAR_DIRECTION_COUNT = UNKNOWN;

    /**
     * @var int
     * @cvalue UBLOCK_NO_BLOCK
     */
    public const BLOCK_CODE_NO_BLOCK = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BASIC_LATIN
     */
    public const BLOCK_CODE_BASIC_LATIN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LATIN_1_SUPPLEMENT
     */
    public const BLOCK_CODE_LATIN_1_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LATIN_EXTENDED_A
     */
    public const BLOCK_CODE_LATIN_EXTENDED_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LATIN_EXTENDED_B
     */
    public const BLOCK_CODE_LATIN_EXTENDED_B = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_IPA_EXTENSIONS
     */
    public const BLOCK_CODE_IPA_EXTENSIONS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SPACING_MODIFIER_LETTERS
     */
    public const BLOCK_CODE_SPACING_MODIFIER_LETTERS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_COMBINING_DIACRITICAL_MARKS
     */
    public const BLOCK_CODE_COMBINING_DIACRITICAL_MARKS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GREEK
     */
    public const BLOCK_CODE_GREEK = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CYRILLIC
     */
    public const BLOCK_CODE_CYRILLIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ARMENIAN
     */
    public const BLOCK_CODE_ARMENIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HEBREW
     */
    public const BLOCK_CODE_HEBREW = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ARABIC
     */
    public const BLOCK_CODE_ARABIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SYRIAC
     */
    public const BLOCK_CODE_SYRIAC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_THAANA
     */
    public const BLOCK_CODE_THAANA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_DEVANAGARI
     */
    public const BLOCK_CODE_DEVANAGARI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BENGALI
     */
    public const BLOCK_CODE_BENGALI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GURMUKHI
     */
    public const BLOCK_CODE_GURMUKHI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GUJARATI
     */
    public const BLOCK_CODE_GUJARATI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ORIYA
     */
    public const BLOCK_CODE_ORIYA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TAMIL
     */
    public const BLOCK_CODE_TAMIL = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TELUGU
     */
    public const BLOCK_CODE_TELUGU = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KANNADA
     */
    public const BLOCK_CODE_KANNADA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MALAYALAM
     */
    public const BLOCK_CODE_MALAYALAM = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SINHALA
     */
    public const BLOCK_CODE_SINHALA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_THAI
     */
    public const BLOCK_CODE_THAI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LAO
     */
    public const BLOCK_CODE_LAO = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TIBETAN
     */
    public const BLOCK_CODE_TIBETAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MYANMAR
     */
    public const BLOCK_CODE_MYANMAR = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GEORGIAN
     */
    public const BLOCK_CODE_GEORGIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HANGUL_JAMO
     */
    public const BLOCK_CODE_HANGUL_JAMO = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ETHIOPIC
     */
    public const BLOCK_CODE_ETHIOPIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CHEROKEE
     */
    public const BLOCK_CODE_CHEROKEE = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS
     */
    public const BLOCK_CODE_UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_OGHAM
     */
    public const BLOCK_CODE_OGHAM = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_RUNIC
     */
    public const BLOCK_CODE_RUNIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KHMER
     */
    public const BLOCK_CODE_KHMER = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MONGOLIAN
     */
    public const BLOCK_CODE_MONGOLIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LATIN_EXTENDED_ADDITIONAL
     */
    public const BLOCK_CODE_LATIN_EXTENDED_ADDITIONAL = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GREEK_EXTENDED
     */
    public const BLOCK_CODE_GREEK_EXTENDED = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GENERAL_PUNCTUATION
     */
    public const BLOCK_CODE_GENERAL_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SUPERSCRIPTS_AND_SUBSCRIPTS
     */
    public const BLOCK_CODE_SUPERSCRIPTS_AND_SUBSCRIPTS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CURRENCY_SYMBOLS
     */
    public const BLOCK_CODE_CURRENCY_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_COMBINING_MARKS_FOR_SYMBOLS
     */
    public const BLOCK_CODE_COMBINING_MARKS_FOR_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LETTERLIKE_SYMBOLS
     */
    public const BLOCK_CODE_LETTERLIKE_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_NUMBER_FORMS
     */
    public const BLOCK_CODE_NUMBER_FORMS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ARROWS
     */
    public const BLOCK_CODE_ARROWS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MATHEMATICAL_OPERATORS
     */
    public const BLOCK_CODE_MATHEMATICAL_OPERATORS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MISCELLANEOUS_TECHNICAL
     */
    public const BLOCK_CODE_MISCELLANEOUS_TECHNICAL = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CONTROL_PICTURES
     */
    public const BLOCK_CODE_CONTROL_PICTURES = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_OPTICAL_CHARACTER_RECOGNITION
     */
    public const BLOCK_CODE_OPTICAL_CHARACTER_RECOGNITION = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ENCLOSED_ALPHANUMERICS
     */
    public const BLOCK_CODE_ENCLOSED_ALPHANUMERICS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BOX_DRAWING
     */
    public const BLOCK_CODE_BOX_DRAWING = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BLOCK_ELEMENTS
     */
    public const BLOCK_CODE_BLOCK_ELEMENTS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GEOMETRIC_SHAPES
     */
    public const BLOCK_CODE_GEOMETRIC_SHAPES = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MISCELLANEOUS_SYMBOLS
     */
    public const BLOCK_CODE_MISCELLANEOUS_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_DINGBATS
     */
    public const BLOCK_CODE_DINGBATS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BRAILLE_PATTERNS
     */
    public const BLOCK_CODE_BRAILLE_PATTERNS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_RADICALS_SUPPLEMENT
     */
    public const BLOCK_CODE_CJK_RADICALS_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KANGXI_RADICALS
     */
    public const BLOCK_CODE_KANGXI_RADICALS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_IDEOGRAPHIC_DESCRIPTION_CHARACTERS
     */
    public const BLOCK_CODE_IDEOGRAPHIC_DESCRIPTION_CHARACTERS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_SYMBOLS_AND_PUNCTUATION
     */
    public const BLOCK_CODE_CJK_SYMBOLS_AND_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HIRAGANA
     */
    public const BLOCK_CODE_HIRAGANA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KATAKANA
     */
    public const BLOCK_CODE_KATAKANA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BOPOMOFO
     */
    public const BLOCK_CODE_BOPOMOFO = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HANGUL_COMPATIBILITY_JAMO
     */
    public const BLOCK_CODE_HANGUL_COMPATIBILITY_JAMO = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KANBUN
     */
    public const BLOCK_CODE_KANBUN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BOPOMOFO_EXTENDED
     */
    public const BLOCK_CODE_BOPOMOFO_EXTENDED = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ENCLOSED_CJK_LETTERS_AND_MONTHS
     */
    public const BLOCK_CODE_ENCLOSED_CJK_LETTERS_AND_MONTHS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_COMPATIBILITY
     */
    public const BLOCK_CODE_CJK_COMPATIBILITY = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_A
     */
    public const BLOCK_CODE_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_UNIFIED_IDEOGRAPHS
     */
    public const BLOCK_CODE_CJK_UNIFIED_IDEOGRAPHS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_YI_SYLLABLES
     */
    public const BLOCK_CODE_YI_SYLLABLES = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_YI_RADICALS
     */
    public const BLOCK_CODE_YI_RADICALS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HANGUL_SYLLABLES
     */
    public const BLOCK_CODE_HANGUL_SYLLABLES = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HIGH_SURROGATES
     */
    public const BLOCK_CODE_HIGH_SURROGATES = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HIGH_PRIVATE_USE_SURROGATES
     */
    public const BLOCK_CODE_HIGH_PRIVATE_USE_SURROGATES = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LOW_SURROGATES
     */
    public const BLOCK_CODE_LOW_SURROGATES = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PRIVATE_USE_AREA
     */
    public const BLOCK_CODE_PRIVATE_USE_AREA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PRIVATE_USE
     */
    public const BLOCK_CODE_PRIVATE_USE = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_COMPATIBILITY_IDEOGRAPHS
     */
    public const BLOCK_CODE_CJK_COMPATIBILITY_IDEOGRAPHS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ALPHABETIC_PRESENTATION_FORMS
     */
    public const BLOCK_CODE_ALPHABETIC_PRESENTATION_FORMS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ARABIC_PRESENTATION_FORMS_A
     */
    public const BLOCK_CODE_ARABIC_PRESENTATION_FORMS_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_COMBINING_HALF_MARKS
     */
    public const BLOCK_CODE_COMBINING_HALF_MARKS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_COMPATIBILITY_FORMS
     */
    public const BLOCK_CODE_CJK_COMPATIBILITY_FORMS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SMALL_FORM_VARIANTS
     */
    public const BLOCK_CODE_SMALL_FORM_VARIANTS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ARABIC_PRESENTATION_FORMS_B
     */
    public const BLOCK_CODE_ARABIC_PRESENTATION_FORMS_B = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SPECIALS
     */
    public const BLOCK_CODE_SPECIALS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HALFWIDTH_AND_FULLWIDTH_FORMS
     */
    public const BLOCK_CODE_HALFWIDTH_AND_FULLWIDTH_FORMS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_OLD_ITALIC
     */
    public const BLOCK_CODE_OLD_ITALIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GOTHIC
     */
    public const BLOCK_CODE_GOTHIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_DESERET
     */
    public const BLOCK_CODE_DESERET = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BYZANTINE_MUSICAL_SYMBOLS
     */
    public const BLOCK_CODE_BYZANTINE_MUSICAL_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MUSICAL_SYMBOLS
     */
    public const BLOCK_CODE_MUSICAL_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MATHEMATICAL_ALPHANUMERIC_SYMBOLS
     */
    public const BLOCK_CODE_MATHEMATICAL_ALPHANUMERIC_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_B
     */
    public const BLOCK_CODE_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_B = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_COMPATIBILITY_IDEOGRAPHS_SUPPLEMENT
     */
    public const BLOCK_CODE_CJK_COMPATIBILITY_IDEOGRAPHS_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TAGS
     */
    public const BLOCK_CODE_TAGS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CYRILLIC_SUPPLEMENT
     */
    public const BLOCK_CODE_CYRILLIC_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CYRILLIC_SUPPLEMENTARY
     */
    public const BLOCK_CODE_CYRILLIC_SUPPLEMENTARY = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TAGALOG
     */
    public const BLOCK_CODE_TAGALOG = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HANUNOO
     */
    public const BLOCK_CODE_HANUNOO = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BUHID
     */
    public const BLOCK_CODE_BUHID = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TAGBANWA
     */
    public const BLOCK_CODE_TAGBANWA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MISCELLANEOUS_MATHEMATICAL_SYMBOLS_A
     */
    public const BLOCK_CODE_MISCELLANEOUS_MATHEMATICAL_SYMBOLS_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SUPPLEMENTAL_ARROWS_A
     */
    public const BLOCK_CODE_SUPPLEMENTAL_ARROWS_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SUPPLEMENTAL_ARROWS_B
     */
    public const BLOCK_CODE_SUPPLEMENTAL_ARROWS_B = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MISCELLANEOUS_MATHEMATICAL_SYMBOLS_B
     */
    public const BLOCK_CODE_MISCELLANEOUS_MATHEMATICAL_SYMBOLS_B = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SUPPLEMENTAL_MATHEMATICAL_OPERATORS
     */
    public const BLOCK_CODE_SUPPLEMENTAL_MATHEMATICAL_OPERATORS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KATAKANA_PHONETIC_EXTENSIONS
     */
    public const BLOCK_CODE_KATAKANA_PHONETIC_EXTENSIONS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_VARIATION_SELECTORS
     */
    public const BLOCK_CODE_VARIATION_SELECTORS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SUPPLEMENTARY_PRIVATE_USE_AREA_A
     */
    public const BLOCK_CODE_SUPPLEMENTARY_PRIVATE_USE_AREA_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SUPPLEMENTARY_PRIVATE_USE_AREA_B
     */
    public const BLOCK_CODE_SUPPLEMENTARY_PRIVATE_USE_AREA_B = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LIMBU
     */
    public const BLOCK_CODE_LIMBU = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TAI_LE
     */
    public const BLOCK_CODE_TAI_LE = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KHMER_SYMBOLS
     */
    public const BLOCK_CODE_KHMER_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PHONETIC_EXTENSIONS
     */
    public const BLOCK_CODE_PHONETIC_EXTENSIONS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MISCELLANEOUS_SYMBOLS_AND_ARROWS
     */
    public const BLOCK_CODE_MISCELLANEOUS_SYMBOLS_AND_ARROWS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_YIJING_HEXAGRAM_SYMBOLS
     */
    public const BLOCK_CODE_YIJING_HEXAGRAM_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LINEAR_B_SYLLABARY
     */
    public const BLOCK_CODE_LINEAR_B_SYLLABARY = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LINEAR_B_IDEOGRAMS
     */
    public const BLOCK_CODE_LINEAR_B_IDEOGRAMS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_AEGEAN_NUMBERS
     */
    public const BLOCK_CODE_AEGEAN_NUMBERS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_UGARITIC
     */
    public const BLOCK_CODE_UGARITIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SHAVIAN
     */
    public const BLOCK_CODE_SHAVIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_OSMANYA
     */
    public const BLOCK_CODE_OSMANYA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CYPRIOT_SYLLABARY
     */
    public const BLOCK_CODE_CYPRIOT_SYLLABARY = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TAI_XUAN_JING_SYMBOLS
     */
    public const BLOCK_CODE_TAI_XUAN_JING_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_VARIATION_SELECTORS_SUPPLEMENT
     */
    public const BLOCK_CODE_VARIATION_SELECTORS_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ANCIENT_GREEK_MUSICAL_NOTATION
     */
    public const BLOCK_CODE_ANCIENT_GREEK_MUSICAL_NOTATION = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ANCIENT_GREEK_NUMBERS
     */
    public const BLOCK_CODE_ANCIENT_GREEK_NUMBERS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ARABIC_SUPPLEMENT
     */
    public const BLOCK_CODE_ARABIC_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BUGINESE
     */
    public const BLOCK_CODE_BUGINESE = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_STROKES
     */
    public const BLOCK_CODE_CJK_STROKES = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_COMBINING_DIACRITICAL_MARKS_SUPPLEMENT
     */
    public const BLOCK_CODE_COMBINING_DIACRITICAL_MARKS_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_COPTIC
     */
    public const BLOCK_CODE_COPTIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ETHIOPIC_EXTENDED
     */
    public const BLOCK_CODE_ETHIOPIC_EXTENDED = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ETHIOPIC_SUPPLEMENT
     */
    public const BLOCK_CODE_ETHIOPIC_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GEORGIAN_SUPPLEMENT
     */
    public const BLOCK_CODE_GEORGIAN_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GLAGOLITIC
     */
    public const BLOCK_CODE_GLAGOLITIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KHAROSHTHI
     */
    public const BLOCK_CODE_KHAROSHTHI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MODIFIER_TONE_LETTERS
     */
    public const BLOCK_CODE_MODIFIER_TONE_LETTERS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_NEW_TAI_LUE
     */
    public const BLOCK_CODE_NEW_TAI_LUE = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_OLD_PERSIAN
     */
    public const BLOCK_CODE_OLD_PERSIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PHONETIC_EXTENSIONS_SUPPLEMENT
     */
    public const BLOCK_CODE_PHONETIC_EXTENSIONS_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SUPPLEMENTAL_PUNCTUATION
     */
    public const BLOCK_CODE_SUPPLEMENTAL_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SYLOTI_NAGRI
     */
    public const BLOCK_CODE_SYLOTI_NAGRI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TIFINAGH
     */
    public const BLOCK_CODE_TIFINAGH = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_VERTICAL_FORMS
     */
    public const BLOCK_CODE_VERTICAL_FORMS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_NKO
     */
    public const BLOCK_CODE_NKO = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BALINESE
     */
    public const BLOCK_CODE_BALINESE = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LATIN_EXTENDED_C
     */
    public const BLOCK_CODE_LATIN_EXTENDED_C = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LATIN_EXTENDED_D
     */
    public const BLOCK_CODE_LATIN_EXTENDED_D = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PHAGS_PA
     */
    public const BLOCK_CODE_PHAGS_PA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PHOENICIAN
     */
    public const BLOCK_CODE_PHOENICIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CUNEIFORM
     */
    public const BLOCK_CODE_CUNEIFORM = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CUNEIFORM_NUMBERS_AND_PUNCTUATION
     */
    public const BLOCK_CODE_CUNEIFORM_NUMBERS_AND_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_COUNTING_ROD_NUMERALS
     */
    public const BLOCK_CODE_COUNTING_ROD_NUMERALS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SUNDANESE
     */
    public const BLOCK_CODE_SUNDANESE = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LEPCHA
     */
    public const BLOCK_CODE_LEPCHA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_OL_CHIKI
     */
    public const BLOCK_CODE_OL_CHIKI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CYRILLIC_EXTENDED_A
     */
    public const BLOCK_CODE_CYRILLIC_EXTENDED_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_VAI
     */
    public const BLOCK_CODE_VAI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CYRILLIC_EXTENDED_B
     */
    public const BLOCK_CODE_CYRILLIC_EXTENDED_B = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SAURASHTRA
     */
    public const BLOCK_CODE_SAURASHTRA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KAYAH_LI
     */
    public const BLOCK_CODE_KAYAH_LI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_REJANG
     */
    public const BLOCK_CODE_REJANG = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CHAM
     */
    public const BLOCK_CODE_CHAM = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ANCIENT_SYMBOLS
     */
    public const BLOCK_CODE_ANCIENT_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PHAISTOS_DISC
     */
    public const BLOCK_CODE_PHAISTOS_DISC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LYCIAN
     */
    public const BLOCK_CODE_LYCIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CARIAN
     */
    public const BLOCK_CODE_CARIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LYDIAN
     */
    public const BLOCK_CODE_LYDIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MAHJONG_TILES
     */
    public const BLOCK_CODE_MAHJONG_TILES = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_DOMINO_TILES
     */
    public const BLOCK_CODE_DOMINO_TILES = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SAMARITAN
     */
    public const BLOCK_CODE_SAMARITAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS_EXTENDED
     */
    public const BLOCK_CODE_UNIFIED_CANADIAN_ABORIGINAL_SYLLABICS_EXTENDED = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TAI_THAM
     */
    public const BLOCK_CODE_TAI_THAM = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_VEDIC_EXTENSIONS
     */
    public const BLOCK_CODE_VEDIC_EXTENSIONS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LISU
     */
    public const BLOCK_CODE_LISU = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BAMUM
     */
    public const BLOCK_CODE_BAMUM = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_COMMON_INDIC_NUMBER_FORMS
     */
    public const BLOCK_CODE_COMMON_INDIC_NUMBER_FORMS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_DEVANAGARI_EXTENDED
     */
    public const BLOCK_CODE_DEVANAGARI_EXTENDED = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HANGUL_JAMO_EXTENDED_A
     */
    public const BLOCK_CODE_HANGUL_JAMO_EXTENDED_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_JAVANESE
     */
    public const BLOCK_CODE_JAVANESE = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MYANMAR_EXTENDED_A
     */
    public const BLOCK_CODE_MYANMAR_EXTENDED_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TAI_VIET
     */
    public const BLOCK_CODE_TAI_VIET = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MEETEI_MAYEK
     */
    public const BLOCK_CODE_MEETEI_MAYEK = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_HANGUL_JAMO_EXTENDED_B
     */
    public const BLOCK_CODE_HANGUL_JAMO_EXTENDED_B = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_IMPERIAL_ARAMAIC
     */
    public const BLOCK_CODE_IMPERIAL_ARAMAIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_OLD_SOUTH_ARABIAN
     */
    public const BLOCK_CODE_OLD_SOUTH_ARABIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_AVESTAN
     */
    public const BLOCK_CODE_AVESTAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_INSCRIPTIONAL_PARTHIAN
     */
    public const BLOCK_CODE_INSCRIPTIONAL_PARTHIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_INSCRIPTIONAL_PAHLAVI
     */
    public const BLOCK_CODE_INSCRIPTIONAL_PAHLAVI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_OLD_TURKIC
     */
    public const BLOCK_CODE_OLD_TURKIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_RUMI_NUMERAL_SYMBOLS
     */
    public const BLOCK_CODE_RUMI_NUMERAL_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KAITHI
     */
    public const BLOCK_CODE_KAITHI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_EGYPTIAN_HIEROGLYPHS
     */
    public const BLOCK_CODE_EGYPTIAN_HIEROGLYPHS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ENCLOSED_ALPHANUMERIC_SUPPLEMENT
     */
    public const BLOCK_CODE_ENCLOSED_ALPHANUMERIC_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ENCLOSED_IDEOGRAPHIC_SUPPLEMENT
     */
    public const BLOCK_CODE_ENCLOSED_IDEOGRAPHIC_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C
     */
    public const BLOCK_CODE_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_C = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MANDAIC
     */
    public const BLOCK_CODE_MANDAIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BATAK
     */
    public const BLOCK_CODE_BATAK = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ETHIOPIC_EXTENDED_A
     */
    public const BLOCK_CODE_ETHIOPIC_EXTENDED_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BRAHMI
     */
    public const BLOCK_CODE_BRAHMI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_BAMUM_SUPPLEMENT
     */
    public const BLOCK_CODE_BAMUM_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KANA_SUPPLEMENT
     */
    public const BLOCK_CODE_KANA_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PLAYING_CARDS
     */
    public const BLOCK_CODE_PLAYING_CARDS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MISCELLANEOUS_SYMBOLS_AND_PICTOGRAPHS
     */
    public const BLOCK_CODE_MISCELLANEOUS_SYMBOLS_AND_PICTOGRAPHS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_EMOTICONS
     */
    public const BLOCK_CODE_EMOTICONS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TRANSPORT_AND_MAP_SYMBOLS
     */
    public const BLOCK_CODE_TRANSPORT_AND_MAP_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ALCHEMICAL_SYMBOLS
     */
    public const BLOCK_CODE_ALCHEMICAL_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_D
     */
    public const BLOCK_CODE_CJK_UNIFIED_IDEOGRAPHS_EXTENSION_D = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ARABIC_EXTENDED_A
     */
    public const BLOCK_CODE_ARABIC_EXTENDED_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ARABIC_MATHEMATICAL_ALPHABETIC_SYMBOLS
     */
    public const BLOCK_CODE_ARABIC_MATHEMATICAL_ALPHABETIC_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CHAKMA
     */
    public const BLOCK_CODE_CHAKMA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MEETEI_MAYEK_EXTENSIONS
     */
    public const BLOCK_CODE_MEETEI_MAYEK_EXTENSIONS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MEROITIC_CURSIVE
     */
    public const BLOCK_CODE_MEROITIC_CURSIVE = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MEROITIC_HIEROGLYPHS
     */
    public const BLOCK_CODE_MEROITIC_HIEROGLYPHS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MIAO
     */
    public const BLOCK_CODE_MIAO = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SHARADA
     */
    public const BLOCK_CODE_SHARADA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SORA_SOMPENG
     */
    public const BLOCK_CODE_SORA_SOMPENG = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SUNDANESE_SUPPLEMENT
     */
    public const BLOCK_CODE_SUNDANESE_SUPPLEMENT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TAKRI
     */
    public const BLOCK_CODE_TAKRI = UNKNOWN;
#if U_ICU_VERSION_MAJOR_NUM >= 54
    /**
     * @var int
     * @cvalue UBLOCK_BASSA_VAH
     */
    public const BLOCK_CODE_BASSA_VAH = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_CAUCASIAN_ALBANIAN
     */
    public const BLOCK_CODE_CAUCASIAN_ALBANIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_COPTIC_EPACT_NUMBERS
     */
    public const BLOCK_CODE_COPTIC_EPACT_NUMBERS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_COMBINING_DIACRITICAL_MARKS_EXTENDED
     */
    public const BLOCK_CODE_COMBINING_DIACRITICAL_MARKS_EXTENDED = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_DUPLOYAN
     */
    public const BLOCK_CODE_DUPLOYAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ELBASAN
     */
    public const BLOCK_CODE_ELBASAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GEOMETRIC_SHAPES_EXTENDED
     */
    public const BLOCK_CODE_GEOMETRIC_SHAPES_EXTENDED = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_GRANTHA
     */
    public const BLOCK_CODE_GRANTHA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KHOJKI
     */
    public const BLOCK_CODE_KHOJKI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_KHUDAWADI
     */
    public const BLOCK_CODE_KHUDAWADI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LATIN_EXTENDED_E
     */
    public const BLOCK_CODE_LATIN_EXTENDED_E = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_LINEAR_A
     */
    public const BLOCK_CODE_LINEAR_A = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MAHAJANI
     */
    public const BLOCK_CODE_MAHAJANI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MANICHAEAN
     */
    public const BLOCK_CODE_MANICHAEAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MENDE_KIKAKUI
     */
    public const BLOCK_CODE_MENDE_KIKAKUI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MODI
     */
    public const BLOCK_CODE_MODI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MRO
     */
    public const BLOCK_CODE_MRO = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_MYANMAR_EXTENDED_B
     */
    public const BLOCK_CODE_MYANMAR_EXTENDED_B = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_NABATAEAN
     */
    public const BLOCK_CODE_NABATAEAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_OLD_NORTH_ARABIAN
     */
    public const BLOCK_CODE_OLD_NORTH_ARABIAN = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_OLD_PERMIC
     */
    public const BLOCK_CODE_OLD_PERMIC = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_ORNAMENTAL_DINGBATS
     */
    public const BLOCK_CODE_ORNAMENTAL_DINGBATS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PAHAWH_HMONG
     */
    public const BLOCK_CODE_PAHAWH_HMONG = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PALMYRENE
     */
    public const BLOCK_CODE_PALMYRENE = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PAU_CIN_HAU
     */
    public const BLOCK_CODE_PAU_CIN_HAU = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_PSALTER_PAHLAVI
     */
    public const BLOCK_CODE_PSALTER_PAHLAVI = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SHORTHAND_FORMAT_CONTROLS
     */
    public const BLOCK_CODE_SHORTHAND_FORMAT_CONTROLS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SIDDHAM
     */
    public const BLOCK_CODE_SIDDHAM = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SINHALA_ARCHAIC_NUMBERS
     */
    public const BLOCK_CODE_SINHALA_ARCHAIC_NUMBERS = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_SUPPLEMENTAL_ARROWS_C
     */
    public const BLOCK_CODE_SUPPLEMENTAL_ARROWS_C = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_TIRHUTA
     */
    public const BLOCK_CODE_TIRHUTA = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_WARANG_CITI
     */
    public const BLOCK_CODE_WARANG_CITI = UNKNOWN;
#endif
    /**
     * @var int
     * @cvalue UBLOCK_COUNT
     */
    public const BLOCK_CODE_COUNT = UNKNOWN;
    /**
     * @var int
     * @cvalue UBLOCK_INVALID_CODE
     */
    public const BLOCK_CODE_INVALID_CODE = UNKNOWN;

    /* UBidiPairedBracketType - http://icu-project.org/apiref/icu4c/uchar_8h.html#af954219aa1df452657ec355221c6703d */

#if U_ICU_VERSION_MAJOR_NUM >= 52
    /**
     * @var int
     * @cvalue U_BPT_NONE
     */
    public const BPT_NONE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_BPT_OPEN
     */
    public const BPT_OPEN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_BPT_CLOSE
     */
    public const BPT_CLOSE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_BPT_COUNT
     */
    public const BPT_COUNT = UNKNOWN;
#endif

    /* UEastAsianWidth - http://icu-project.org/apiref/icu4c/uchar_8h.html#a95cc2ca2f9cfd6d0c63eee2c65951333 */

    /**
     * @var int
     * @cvalue U_EA_NEUTRAL
     */
    public const EA_NEUTRAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_EA_AMBIGUOUS
     */
    public const EA_AMBIGUOUS = UNKNOWN;
    /**
     * @var int
     * @cvalue U_EA_HALFWIDTH
     */
    public const EA_HALFWIDTH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_EA_FULLWIDTH
     */
    public const EA_FULLWIDTH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_EA_NARROW
     */
    public const EA_NARROW = UNKNOWN;
    /**
     * @var int
     * @cvalue U_EA_WIDE
     */
    public const EA_WIDE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_EA_COUNT
     */
    public const EA_COUNT = UNKNOWN;

    /* UCharNameChoice - http://icu-project.org/apiref/icu4c/uchar_8h.html#a2ba37edcca62eff48226e8096035addf */

    /**
     * @var int
     * @cvalue U_UNICODE_CHAR_NAME
     */
    public const UNICODE_CHAR_NAME = UNKNOWN;
    /**
     * @var int
     * @cvalue U_UNICODE_10_CHAR_NAME
     */
    public const UNICODE_10_CHAR_NAME = UNKNOWN;
    /**
     * @var int
     * @cvalue U_EXTENDED_CHAR_NAME
     */
    public const EXTENDED_CHAR_NAME = UNKNOWN;
    /**
     * @var int
     * @cvalue U_CHAR_NAME_ALIAS
     */
    public const CHAR_NAME_ALIAS = UNKNOWN;
    /**
     * @var int
     * @cvalue U_CHAR_NAME_CHOICE_COUNT
     */
    public const CHAR_NAME_CHOICE_COUNT = UNKNOWN;

    /* UPropertyNameChoice - http://icu-project.org/apiref/icu4c/uchar_8h.html#a5056494c7d5a2c7185f3c464f48fe5d1 */

    /**
     * @var int
     * @cvalue U_SHORT_PROPERTY_NAME
     */
    public const SHORT_PROPERTY_NAME = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LONG_PROPERTY_NAME
     */
    public const LONG_PROPERTY_NAME = UNKNOWN;
    /**
     * @var int
     * @cvalue U_PROPERTY_NAME_CHOICE_COUNT
     */
    public const PROPERTY_NAME_CHOICE_COUNT = UNKNOWN;

    /* UDecompositionType - http://icu-project.org/apiref/icu4c/uchar_8h.html#ae2c56994fcf28062c7e77beb671533f5 */

    /**
     * @var int
     * @cvalue U_DT_NONE
     */
    public const DT_NONE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_CANONICAL
     */
    public const DT_CANONICAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_COMPAT
     */
    public const DT_COMPAT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_CIRCLE
     */
    public const DT_CIRCLE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_FINAL
     */
    public const DT_FINAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_FONT
     */
    public const DT_FONT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_FRACTION
     */
    public const DT_FRACTION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_INITIAL
     */
    public const DT_INITIAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_ISOLATED
     */
    public const DT_ISOLATED = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_MEDIAL
     */
    public const DT_MEDIAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_NARROW
     */
    public const DT_NARROW = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_NOBREAK
     */
    public const DT_NOBREAK = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_SMALL
     */
    public const DT_SMALL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_SQUARE
     */
    public const DT_SQUARE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_SUB
     */
    public const DT_SUB = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_SUPER
     */
    public const DT_SUPER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_VERTICAL
     */
    public const DT_VERTICAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_WIDE
     */
    public const DT_WIDE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_DT_COUNT
     */
    public const DT_COUNT = UNKNOWN;

    /* UJoiningType - http://icu-project.org/apiref/icu4c/uchar_8h.html#a3ce1ce20e7f3b8534eb3490ad3aba3dd */

    /**
     * @var int
     * @cvalue U_JT_NON_JOINING
     */
    public const JT_NON_JOINING = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JT_JOIN_CAUSING
     */
    public const JT_JOIN_CAUSING = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JT_DUAL_JOINING
     */
    public const JT_DUAL_JOINING = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JT_LEFT_JOINING
     */
    public const JT_LEFT_JOINING = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JT_RIGHT_JOINING
     */
    public const JT_RIGHT_JOINING = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JT_TRANSPARENT
     */
    public const JT_TRANSPARENT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JT_COUNT
     */
    public const JT_COUNT = UNKNOWN;

    /* UJoiningGroup - http://icu-project.org/apiref/icu4c/uchar_8h.html#a7887844ec0872e6e9a283e0825fcae65 */

    /**
     * @var int
     * @cvalue U_JG_NO_JOINING_GROUP
     */
    public const JG_NO_JOINING_GROUP = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_AIN
     */
    public const JG_AIN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_ALAPH
     */
    public const JG_ALAPH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_ALEF
     */
    public const JG_ALEF = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_BEH
     */
    public const JG_BEH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_BETH
     */
    public const JG_BETH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_DAL
     */
    public const JG_DAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_DALATH_RISH
     */
    public const JG_DALATH_RISH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_E
     */
    public const JG_E = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_FEH
     */
    public const JG_FEH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_FINAL_SEMKATH
     */
    public const JG_FINAL_SEMKATH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_GAF
     */
    public const JG_GAF = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_GAMAL
     */
    public const JG_GAMAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_HAH
     */
    public const JG_HAH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_TEH_MARBUTA_GOAL
     */
    public const JG_TEH_MARBUTA_GOAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_HAMZA_ON_HEH_GOAL
     */
    public const JG_HAMZA_ON_HEH_GOAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_HE
     */
    public const JG_HE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_HEH
     */
    public const JG_HEH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_HEH_GOAL
     */
    public const JG_HEH_GOAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_HETH
     */
    public const JG_HETH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_KAF
     */
    public const JG_KAF = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_KAPH
     */
    public const JG_KAPH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_KNOTTED_HEH
     */
    public const JG_KNOTTED_HEH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_LAM
     */
    public const JG_LAM = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_LAMADH
     */
    public const JG_LAMADH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MEEM
     */
    public const JG_MEEM = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MIM
     */
    public const JG_MIM = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_NOON
     */
    public const JG_NOON = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_NUN
     */
    public const JG_NUN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_PE
     */
    public const JG_PE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_QAF
     */
    public const JG_QAF = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_QAPH
     */
    public const JG_QAPH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_REH
     */
    public const JG_REH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_REVERSED_PE
     */
    public const JG_REVERSED_PE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_SAD
     */
    public const JG_SAD = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_SADHE
     */
    public const JG_SADHE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_SEEN
     */
    public const JG_SEEN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_SEMKATH
     */
    public const JG_SEMKATH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_SHIN
     */
    public const JG_SHIN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_SWASH_KAF
     */
    public const JG_SWASH_KAF = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_SYRIAC_WAW
     */
    public const JG_SYRIAC_WAW = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_TAH
     */
    public const JG_TAH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_TAW
     */
    public const JG_TAW = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_TEH_MARBUTA
     */
    public const JG_TEH_MARBUTA = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_TETH
     */
    public const JG_TETH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_WAW
     */
    public const JG_WAW = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_YEH
     */
    public const JG_YEH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_YEH_BARREE
     */
    public const JG_YEH_BARREE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_YEH_WITH_TAIL
     */
    public const JG_YEH_WITH_TAIL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_YUDH
     */
    public const JG_YUDH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_YUDH_HE
     */
    public const JG_YUDH_HE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_ZAIN
     */
    public const JG_ZAIN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_FE
     */
    public const JG_FE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_KHAPH
     */
    public const JG_KHAPH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_ZHAIN
     */
    public const JG_ZHAIN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_BURUSHASKI_YEH_BARREE
     */
    public const JG_BURUSHASKI_YEH_BARREE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_FARSI_YEH
     */
    public const JG_FARSI_YEH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_NYA
     */
    public const JG_NYA = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_ROHINGYA_YEH
     */
    public const JG_ROHINGYA_YEH = UNKNOWN;
#if U_ICU_VERSION_MAJOR_NUM >= 54
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_ALEPH
     */
    public const JG_MANICHAEAN_ALEPH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_AYIN
     */
    public const JG_MANICHAEAN_AYIN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_BETH
     */
    public const JG_MANICHAEAN_BETH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_DALETH
     */
    public const JG_MANICHAEAN_DALETH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_DHAMEDH
     */
    public const JG_MANICHAEAN_DHAMEDH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_FIVE
     */
    public const JG_MANICHAEAN_FIVE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_GIMEL
     */
    public const JG_MANICHAEAN_GIMEL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_HETH
     */
    public const JG_MANICHAEAN_HETH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_HUNDRED
     */
    public const JG_MANICHAEAN_HUNDRED = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_KAPH
     */
    public const JG_MANICHAEAN_KAPH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_LAMEDH
     */
    public const JG_MANICHAEAN_LAMEDH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_MEM
     */
    public const JG_MANICHAEAN_MEM = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_NUN
     */
    public const JG_MANICHAEAN_NUN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_ONE
     */
    public const JG_MANICHAEAN_ONE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_PE
     */
    public const JG_MANICHAEAN_PE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_QOPH
     */
    public const JG_MANICHAEAN_QOPH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_RESH
     */
    public const JG_MANICHAEAN_RESH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_SADHE
     */
    public const JG_MANICHAEAN_SADHE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_SAMEKH
     */
    public const JG_MANICHAEAN_SAMEKH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_TAW
     */
    public const JG_MANICHAEAN_TAW = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_TEN
     */
    public const JG_MANICHAEAN_TEN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_TETH
     */
    public const JG_MANICHAEAN_TETH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_THAMEDH
     */
    public const JG_MANICHAEAN_THAMEDH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_TWENTY
     */
    public const JG_MANICHAEAN_TWENTY = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_WAW
     */
    public const JG_MANICHAEAN_WAW = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_YODH
     */
    public const JG_MANICHAEAN_YODH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_MANICHAEAN_ZAYIN
     */
    public const JG_MANICHAEAN_ZAYIN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_JG_STRAIGHT_WAW
     */
    public const JG_STRAIGHT_WAW = UNKNOWN;
#endif
    /**
     * @var int
     * @cvalue U_JG_COUNT
     */
    public const JG_COUNT = UNKNOWN;

    /* UGraphemeClusterBreak - http://icu-project.org/apiref/icu4c/uchar_8h.html#abb9bae7d2a1c80ce342be4647661fde1 */

    /**
     * @var int
     * @cvalue U_GCB_OTHER
     */
    public const GCB_OTHER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_CONTROL
     */
    public const GCB_CONTROL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_CR
     */
    public const GCB_CR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_EXTEND
     */
    public const GCB_EXTEND = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_L
     */
    public const GCB_L = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_LF
     */
    public const GCB_LF = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_LV
     */
    public const GCB_LV = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_LVT
     */
    public const GCB_LVT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_T
     */
    public const GCB_T = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_V
     */
    public const GCB_V = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_SPACING_MARK
     */
    public const GCB_SPACING_MARK = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_PREPEND
     */
    public const GCB_PREPEND = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_REGIONAL_INDICATOR
     */
    public const GCB_REGIONAL_INDICATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_GCB_COUNT
     */
    public const GCB_COUNT = UNKNOWN;

    /* UWordBreakValues - http://icu-project.org/apiref/icu4c/uchar_8h.html#af70ee907368e663f8dd4b90c7196e15c */

    /**
     * @var int
     * @cvalue U_WB_OTHER
     */
    public const WB_OTHER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_ALETTER
     */
    public const WB_ALETTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_FORMAT
     */
    public const WB_FORMAT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_KATAKANA
     */
    public const WB_KATAKANA = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_MIDLETTER
     */
    public const WB_MIDLETTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_MIDNUM
     */
    public const WB_MIDNUM = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_NUMERIC
     */
    public const WB_NUMERIC = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_EXTENDNUMLET
     */
    public const WB_EXTENDNUMLET = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_CR
     */
    public const WB_CR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_EXTEND
     */
    public const WB_EXTEND = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_LF
     */
    public const WB_LF = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_MIDNUMLET
     */
    public const WB_MIDNUMLET = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_NEWLINE
     */
    public const WB_NEWLINE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_REGIONAL_INDICATOR
     */
    public const WB_REGIONAL_INDICATOR = UNKNOWN;
#if U_ICU_VERSION_MAJOR_NUM >= 52
    /**
     * @var int
     * @cvalue U_WB_HEBREW_LETTER
     */
    public const WB_HEBREW_LETTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_SINGLE_QUOTE
     */
    public const WB_SINGLE_QUOTE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_WB_DOUBLE_QUOTE
     */
    public const WB_DOUBLE_QUOTE = UNKNOWN;
#endif
    /**
     * @var int
     * @cvalue U_WB_COUNT
     */
    public const WB_COUNT = UNKNOWN;

    /* USentenceBreak - http://icu-project.org/apiref/icu4c/uchar_8h.html#a89e9e463c3bae1d2d46b1dbb6f90de0f */

    /**
     * @var int
     * @cvalue U_SB_OTHER
     */
    public const SB_OTHER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_ATERM
     */
    public const SB_ATERM = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_CLOSE
     */
    public const SB_CLOSE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_FORMAT
     */
    public const SB_FORMAT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_LOWER
     */
    public const SB_LOWER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_NUMERIC
     */
    public const SB_NUMERIC = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_OLETTER
     */
    public const SB_OLETTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_SEP
     */
    public const SB_SEP = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_SP
     */
    public const SB_SP = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_STERM
     */
    public const SB_STERM = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_UPPER
     */
    public const SB_UPPER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_CR
     */
    public const SB_CR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_EXTEND
     */
    public const SB_EXTEND = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_LF
     */
    public const SB_LF = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_SCONTINUE
     */
    public const SB_SCONTINUE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_SB_COUNT
     */
    public const SB_COUNT = UNKNOWN;

    /* ULineBreak - http://icu-project.org/apiref/icu4c/uchar_8h.html#a5d1abdf05be22cb9599f804a8506277c */

    /**
     * @var int
     * @cvalue U_LB_UNKNOWN
     */
    public const LB_UNKNOWN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_AMBIGUOUS
     */
    public const LB_AMBIGUOUS = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_ALPHABETIC
     */
    public const LB_ALPHABETIC = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_BREAK_BOTH
     */
    public const LB_BREAK_BOTH = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_BREAK_AFTER
     */
    public const LB_BREAK_AFTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_BREAK_BEFORE
     */
    public const LB_BREAK_BEFORE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_MANDATORY_BREAK
     */
    public const LB_MANDATORY_BREAK = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_CONTINGENT_BREAK
     */
    public const LB_CONTINGENT_BREAK = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_CLOSE_PUNCTUATION
     */
    public const LB_CLOSE_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_COMBINING_MARK
     */
    public const LB_COMBINING_MARK = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_CARRIAGE_RETURN
     */
    public const LB_CARRIAGE_RETURN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_EXCLAMATION
     */
    public const LB_EXCLAMATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_GLUE
     */
    public const LB_GLUE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_HYPHEN
     */
    public const LB_HYPHEN = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_IDEOGRAPHIC
     */
    public const LB_IDEOGRAPHIC = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_INSEPARABLE
     */
    public const LB_INSEPARABLE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_INSEPERABLE
     */
    public const LB_INSEPERABLE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_INFIX_NUMERIC
     */
    public const LB_INFIX_NUMERIC = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_LINE_FEED
     */
    public const LB_LINE_FEED = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_NONSTARTER
     */
    public const LB_NONSTARTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_NUMERIC
     */
    public const LB_NUMERIC = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_OPEN_PUNCTUATION
     */
    public const LB_OPEN_PUNCTUATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_POSTFIX_NUMERIC
     */
    public const LB_POSTFIX_NUMERIC = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_PREFIX_NUMERIC
     */
    public const LB_PREFIX_NUMERIC = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_QUOTATION
     */
    public const LB_QUOTATION = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_COMPLEX_CONTEXT
     */
    public const LB_COMPLEX_CONTEXT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_SURROGATE
     */
    public const LB_SURROGATE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_SPACE
     */
    public const LB_SPACE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_BREAK_SYMBOLS
     */
    public const LB_BREAK_SYMBOLS = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_ZWSPACE
     */
    public const LB_ZWSPACE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_NEXT_LINE
     */
    public const LB_NEXT_LINE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_WORD_JOINER
     */
    public const LB_WORD_JOINER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_H2
     */
    public const LB_H2 = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_H3
     */
    public const LB_H3 = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_JL
     */
    public const LB_JL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_JT
     */
    public const LB_JT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_JV
     */
    public const LB_JV = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_CLOSE_PARENTHESIS
     */
    public const LB_CLOSE_PARENTHESIS = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_CONDITIONAL_JAPANESE_STARTER
     */
    public const LB_CONDITIONAL_JAPANESE_STARTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_HEBREW_LETTER
     */
    public const LB_HEBREW_LETTER = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_REGIONAL_INDICATOR
     */
    public const LB_REGIONAL_INDICATOR = UNKNOWN;
    /**
     * @var int
     * @cvalue U_LB_COUNT
     */
    public const LB_COUNT = UNKNOWN;

    /* UNumericType - http://icu-project.org/apiref/icu4c/uchar_8h.html#adec3e7a6ae3a00274c019b3b2ddaecbe */

    /**
     * @var int
     * @cvalue U_NT_NONE
     */
    public const NT_NONE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_NT_DECIMAL
     */
    public const NT_DECIMAL = UNKNOWN;
    /**
     * @var int
     * @cvalue U_NT_DIGIT
     */
    public const NT_DIGIT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_NT_NUMERIC
     */
    public const NT_NUMERIC = UNKNOWN;
    /**
     * @var int
     * @cvalue U_NT_COUNT
     */
    public const NT_COUNT = UNKNOWN;

    /* UHangulSyllableType - http://icu-project.org/apiref/icu4c/uchar_8h.html#a7cb09027c37ad73571cf541caf002c8f */

    /**
     * @var int
     * @cvalue U_HST_NOT_APPLICABLE
     */
    public const HST_NOT_APPLICABLE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_HST_LEADING_JAMO
     */
    public const HST_LEADING_JAMO = UNKNOWN;
    /**
     * @var int
     * @cvalue U_HST_VOWEL_JAMO
     */
    public const HST_VOWEL_JAMO = UNKNOWN;
    /**
     * @var int
     * @cvalue U_HST_TRAILING_JAMO
     */
    public const HST_TRAILING_JAMO = UNKNOWN;
    /**
     * @var int
     * @cvalue U_HST_LV_SYLLABLE
     */
    public const HST_LV_SYLLABLE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_HST_LVT_SYLLABLE
     */
    public const HST_LVT_SYLLABLE = UNKNOWN;
    /**
     * @var int
     * @cvalue U_HST_COUNT
     */
    public const HST_COUNT = UNKNOWN;

    /* StringOptions - http://icu-project.org/apiref/icu4c/stringoptions_8h.html */

    /**
     * @var int
     * @cvalue U_FOLD_CASE_DEFAULT
     */
    public const FOLD_CASE_DEFAULT = UNKNOWN;
    /**
     * @var int
     * @cvalue U_FOLD_CASE_EXCLUDE_SPECIAL_I
     */
    public const FOLD_CASE_EXCLUDE_SPECIAL_I = UNKNOWN;

    /** @tentative-return-type */
    public static function hasBinaryProperty(int|string $codepoint, int $property): ?bool {}

    /** @tentative-return-type */
    public static function charAge(int|string $codepoint): ?array {}

    /** @tentative-return-type */
    public static function charDigitValue(int|string $codepoint): ?int {}

    /** @tentative-return-type */
    public static function charDirection(int|string $codepoint): ?int {}

    /** @tentative-return-type */
    public static function charFromName(string $name, int $type = IntlChar::UNICODE_CHAR_NAME): ?int {}

    /** @tentative-return-type */
    public static function charMirror(int|string $codepoint): int|string|null {}

    /** @tentative-return-type */
    public static function charName(int|string $codepoint, int $type = IntlChar::UNICODE_CHAR_NAME): ?string {}

    /** @tentative-return-type */
    public static function charType(int|string $codepoint): ?int {}

    /** @tentative-return-type */
    public static function chr(int|string $codepoint): ?string {}

    /** @tentative-return-type */
    public static function digit(int|string $codepoint, int $base = 10): int|false|null {}

    /** @tentative-return-type */
    public static function enumCharNames(int|string $start, int|string $end, callable $callback, int $type = IntlChar::UNICODE_CHAR_NAME): ?bool {} // TODO return values just don't make sense

    /** @tentative-return-type */
    public static function enumCharTypes(callable $callback): void {}

    /** @tentative-return-type */
    public static function foldCase(int|string $codepoint, int $options = IntlChar::FOLD_CASE_DEFAULT): int|string|null {}

    /** @tentative-return-type */
    public static function forDigit(int $digit, int $base = 10): int {}

#if U_ICU_VERSION_MAJOR_NUM >= 52
    /** @tentative-return-type */
    public static function getBidiPairedBracket(int|string $codepoint): int|string|null {}
#endif

    /** @tentative-return-type */
    public static function getBlockCode(int|string $codepoint): ?int {}

    /** @tentative-return-type */
    public static function getCombiningClass(int|string $codepoint): ?int {}

    /** @tentative-return-type */
    public static function getFC_NFKC_Closure(int|string $codepoint): string|false|null {}

    /** @tentative-return-type */
    public static function getIntPropertyMaxValue(int $property): int {}

    /** @tentative-return-type */
    public static function getIntPropertyMinValue(int $property): int {}

    /** @tentative-return-type */
    public static function getIntPropertyValue(int|string $codepoint, int $property): ?int {}

    /** @tentative-return-type */
    public static function getNumericValue(int|string $codepoint): ?float {}

    /** @tentative-return-type */
    public static function getPropertyEnum(string $alias): int {}

    /** @tentative-return-type */
    public static function getPropertyName(int $property, int $type = IntlChar::LONG_PROPERTY_NAME): string|false {}

    /** @tentative-return-type */
    public static function getPropertyValueEnum(int $property, string $name): int {}

    /** @tentative-return-type */
    public static function getPropertyValueName(int $property, int $value, int $type = IntlChar::LONG_PROPERTY_NAME): string|false {}

    /** @tentative-return-type */
    public static function getUnicodeVersion(): array {}

    /** @tentative-return-type */
    public static function isalnum(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isalpha(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isbase(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isblank(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function iscntrl(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isdefined(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isdigit(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isgraph(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isIDIgnorable(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isIDPart(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isIDStart(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isISOControl(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isJavaIDPart(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isJavaIDStart(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isJavaSpaceChar(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function islower(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isMirrored(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isprint(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function ispunct(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isspace(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function istitle(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isUAlphabetic(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isULowercase(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isupper(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isUUppercase(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isUWhiteSpace(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isWhitespace(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function isxdigit(int|string $codepoint): ?bool {}

    /** @tentative-return-type */
    public static function ord(int|string $character): ?int {}

    /** @tentative-return-type */
    public static function tolower(int|string $codepoint): int|string|null {}

    /** @tentative-return-type */
    public static function totitle(int|string $codepoint): int|string|null {}

    /** @tentative-return-type */
    public static function toupper(int|string $codepoint): int|string|null {}
}
